#!/usr/bin/python
# -*- coding: utf-8 -*-

from pathlib import Path
from setuptools import setup

VERSION = open('src/wf/_version.py').readlines()[-1].split()[-1].strip("\"'")
README = Path('README.md').read_text()

setup(
    name='ssa-' + Path().absolute().name,
    version=VERSION,
    description='NRAO Archive Workflow Commands',
    long_description=README,
    author='NRAO SSA Team',
    author_email='dms-ssa@nrao.edu',
    url='TBD',
    license="GPL",
    install_requires=['pika', 'psycopg2', 'cx_Oracle', 'pymygdala', 'pycapo', 'schema'],
    keywords=[],
    packages=['wf'],
    package_dir={'':'src'},
    classifiers=[
        'Programming Language :: Python :: 3.8'
    ],
    entry_points={
        'console_scripts': [
            'wf               = wf.commands:wf',
            'calFileSets      = wf.commands:launch_calibrations',
            'recalDirectories = wf.commands:launch_recalibrations',
            'reingest         = wf.commands:launch_reingest',
            'sdmIngest        = wf.ingest_wf_interfaces:launch_sdm_ingestion',
            'bdfIngest        = wf.ingest_wf_interfaces:launch_bdf_ingestion',
            'restoreToCache   = wf.commands:launch_restore_to_cache',
            'almaRestore      = wf.ous_wf_interfaces:launch_alma_restore',
            'almaImageCube    = wf.ous_wf_interfaces:launch_alma_cube_imaging',
            'almaReimageCube  = wf.ous_wf_interfaces:launch_reimaging_run',
            'audiPass         = wf.ingest_wf_interfaces:launch_alma_image_ingest_qa',
            'vlbaFitsIngest   = wf.ingest_wf_interfaces:launch_idifits_ingestion',
            'vlassQlIngest    = wf.ingest_wf_interfaces:launch_image_ingestion',
            'vlassQlReingest  = wf.ingest_wf_interfaces:launch_image_reingestion',
            'qaClean          = wf.utility_wf_interfaces:launch_deletions',
        ]
    },
)
