import pendulum
from marshmallow import Schema, fields, post_load
from workspaces.schema import WorkflowEventType, WorkflowEvent


class WorkflowEventSchema(Schema):
    """
    Default schema for serializing WorkflowEvents.
    """
    job_name = fields.String()
    job_id = fields.String()
    event_type = fields.Method("get_type", deserialize="load_type")
    timestamp = fields.DateTime()
    log = fields.String()
    retval = fields.Integer(allow_none=True)

    # Enums apparently are not a first-class field type in Marshmallow
    def get_type(self, obj: WorkflowEventType) -> int:
        return obj.type.value

    def load_type(self, value: int) -> WorkflowEventType:
        return next(et for et in WorkflowEventType if et.value == value)

    @post_load
    def make_event(self, data, **kwargs):
        return WorkflowEvent(**data)


workflow_event = WorkflowEventSchema()